@@ -1,3 +1,5 @@
+options(digits=6)
+
 library(automap)
 
 # Data preparation
@@ -6,6 +8,16 @@ coordinates(meuse) =~ x+y
 data(meuse.grid)
 gridded(meuse.grid) =~ x+y
 
+# Fitting some variograms
+variogram = autofitVariogram(zinc ~ soil + ffreq + dist, meuse, 
+    miscFitOptions = list(min.np.bin = 500))
+variogram
+
+# ...and diable the merging, note the difference between the two plots
+variogram = autofitVariogram(zinc ~ soil + ffreq + dist, meuse, 
+    miscFitOptions = list(min.np.bin = 500, merge.small.bins = FALSE))
+variogram
+
 # Ordinary kriging
 kriging_result = autoKrige(zinc~1, meuse, meuse.grid)
 summary(kriging_result)
